@@ -5,6 +5,7 @@ from posixpath import dirname
 from bbb_dlc.version import __version__
 from bbb_dlc.bigbluebutton_api_python import BigBlueButton
 from re import match
+import subprocess
 
 class BBBDLC:
     def run(args):
@@ -14,14 +15,7 @@ class BBBDLC:
         }
 
         try:
-            ncCfg = open(args.ncCfg)
-            ncPath = ""
-
-            for line in ncCfg:
-                line = match("^[\t ']+datadirectory[' =>]+([\/a-zA-Z.0-9]+)", line)
-                if not line: continue
-
-                ncPath = line.group(1)
+            ncPath = subprocess.check_output("/opt/plesk/php/7.3/bin/php" + args.ncDir + "config:system:get datadirectory", shell=True).decode('utf-8').strip()
 
             if ncPath == "": raise NameError('Could not find nextcloud config!')
             
@@ -43,12 +37,12 @@ class BBBDLC:
             os.system("mv " + args.recordId + "/slideshow.mp4 " + args.recordId + "v.mp4")
             os.system("rm -r " + args.recordId)
 
-            os.chdir(get_parent(args.ncCfg, 2))
+            os.chdir(args.ncDir)
             os.system("/opt/plesk/php/7.3/bin/php ./occ files:scan admin")
         except Exception as e:
-            #print(e)
+            print(e)
             errorLog = open("/var/www/vhosts/sapienslab.com.mx/logs/bbb_error_log", "a")
-            errorLog.write(e)
+            errorLog.write(str(e))
             errorLog.close()
         
 def get_parent(dirName, dirUp):
@@ -63,7 +57,7 @@ def get_parser():
         description=('Big Blue Button Converter and Downloader')
     )
 
-    parser.add_argument('ncCfg', type=str, help='Nextcloud cfg file')
+    parser.add_argument('ncDir', type=str, help='Nextcloud install directory')
 
     parser.add_argument('recordId', type=str, help='Recording ID of a lesson')
 
